import RequestNotifications from '@/web-components-submodule/utils/RequestNotifications.js'
import EntityNames from '~/web-components-submodule/standardisation/EntityNames.js'
import IndexNames from '~/web-components-submodule/standardisation/IndexNames.js'
import ESProxyService from '~/web-components-submodule/services/ESProxyService.js'
import ErrorTracking from '~/web-components-submodule/tracking/ErrorTracking.js'

export const state = () => ({
  probeSummaryData: {},
  dataLoaded: false,
})

export const mutations = {
  SET_DATA_LOADED(state, dataLoaded) {
    state.dataLoaded = dataLoaded
  },
  SET_PROBE_SUMMARY_DATA(state, probeSummaryData) {
    state.probeSummaryData = probeSummaryData
  },
}

export const actions = {
  loadData({ commit, state, dispatch }, itemID) {
    const docSource = [
      'pref_name',
      '_metadata.compound_generated.image_file',
      '_metadata.eubopen.in_vivo_use',
      '_metadata.eubopen.is_probe',
      '_metadata.eubopen.is_control',
      '_metadata.eubopen.is_chemogenomic_probe',
      'molecule_structures.canonical_smiles',
      'molecule_structures.standard_inchi_key',
      '_metadata.compound_records.src_id',
    ]
    const entityID = EntityNames.EubopenCompound.entityID
    const indexName = IndexNames.getIndexNameFromEntityID(entityID)

    ESProxyService.getESDocument(indexName, itemID, docSource)
      .then((response) => {
        commit('SET_PROBE_SUMMARY_DATA', response.data._source)
        commit('SET_DATA_LOADED', true)
      })
      .catch((error) => {
        ErrorTracking.trackError(error, this)

        RequestNotifications.dispatchRequestErrorNotification(
          error,
          dispatch,
          `There was an error while loading the name and classification!`
        )
      })
  },
}
